summaryrefslogtreecommitdiff
path: root/src/lib/exceptions.h
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2016-02-12 00:13:14 +0000
committerCarl Hetherington <cth@carlh.net>2016-02-12 00:13:14 +0000
commit80400212e939dc2f3b987cb6df57709929aa5178 (patch)
treeacffc7b335b79b27261610986fcf5fd95f6437ab /src/lib/exceptions.h
parentdb3cd90dadf60df72ebbd95c59b32954f29b9c38 (diff)
Rename SubRip -> TextSubtitle.
Diffstat (limited to 'src/lib/exceptions.h')
-rw-r--r--src/lib/exceptions.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/lib/exceptions.h b/src/lib/exceptions.h
index da8761304..3e7289a50 100644
--- a/src/lib/exceptions.h
+++ b/src/lib/exceptions.h
@@ -211,13 +211,13 @@ public:
PixelFormatError (std::string o, AVPixelFormat f);
};
/** @class SubRipError
* @brief An error that occurs while parsing a SubRip file.
*/
-class SubRipError : public FileError
+class TextSubtitleError : public FileError
{
public:
- SubRipError (std::string, std::string, boost::filesystem::path);
+ TextSubtitleError (std::string, std::string, boost::filesystem::path);
};
class DCPError : public std::runtime_error
@@ -211,13 +211,13 @@ public:
PixelFormatError (std::string o, AVPixelFormat f);
};
-/** @class SubRipError
- * @brief An error that occurs while parsing a SubRip file.
+/** @class TextSubtitleError
+ * @brief An error that occurs while parsing a TextSubtitleError file.
*/